ParameterRange

Struct ParameterRange 

pub struct ParameterRange {
    pub min_share_size: i64,
    pub max_share_size: i64,
    pub min_time_between_verifications: i64,
    pub max_time_between_verifications: i64,
    pub min_time_between_share_updates: i64,
    pub max_time_between_share_updates: i64,
    pub min_unresponsive_deletion_timeout: i64,
    pub max_unresponsive_deletion_timeout: i64,
    pub min_unresponsive_deactivation_timeout: i64,
    pub max_unresponsive_deactivation_timeout: i64,
}

Fields

min_share_size: i64

Minimum and maximum number of bytes the party is willing to store at any given time.

max_share_size: i64min_time_between_verifications: i64

Minimum and maximum interval between verification requests that will be accepted.

max_time_between_verifications: i64min_time_between_share_updates: i64

Minimum and maximum interval between accepting new share updates.

max_time_between_share_updates: i64min_unresponsive_deletion_timeout: i64

Minimum and maximum timeout period (in seconds) after which the other party is considered unresponsive and the pairing may be removed along with all associated data.

max_unresponsive_deletion_timeout: i64min_unresponsive_deactivation_timeout: i64

Minimum and maximum timeout period (in seconds) after which the other party is considered inactive.

max_unresponsive_deactivation_timeout: i64