pub struct ParameterRange {
pub min_share_size: i64,
pub max_share_size: i64,
pub min_time_between_verifications: i64,
pub max_time_between_verifications: i64,
pub min_time_between_share_updates: i64,
pub max_time_between_share_updates: i64,
pub min_unresponsive_deletion_timeout: i64,
pub max_unresponsive_deletion_timeout: i64,
pub min_unresponsive_deactivation_timeout: i64,
pub max_unresponsive_deactivation_timeout: i64,
}Fields
Minimum and maximum number of bytes the party is willing to store at any given time.
min_time_between_verifications: i64Minimum and maximum interval between verification requests that will be accepted.
max_time_between_verifications: i64Minimum and maximum interval between accepting new share updates.
min_unresponsive_deletion_timeout: i64Minimum and maximum timeout period (in seconds) after which the other party is considered unresponsive and the pairing may be removed along with all associated data.
max_unresponsive_deletion_timeout: i64min_unresponsive_deactivation_timeout: i64Minimum and maximum timeout period (in seconds) after which the other party is considered inactive.
max_unresponsive_deactivation_timeout: i64Trait Implementations
Sourceimpl Clone for ParameterRange
impl Clone for ParameterRange
Sourcefn clone(&self) -> ParameterRange
fn clone(&self) -> ParameterRange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParameterRange
impl Debug for ParameterRange
Sourceimpl Default for ParameterRange
impl Default for ParameterRange
Sourceimpl Hash for ParameterRange
impl Hash for ParameterRange
Sourceimpl Message for ParameterRange
impl Message for ParameterRange
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ParameterRange
impl PartialEq for ParameterRange
impl Copy for ParameterRange
impl Eq for ParameterRange
impl StructuralPartialEq for ParameterRange